#---- Biogeographical reconstructions ------#
#-------------- Mormyridae---------------#

#----- Loading packages -----#
library(optimx)       
library(FD)     
library(snow)     
library(parallel)
library(BioGeoBEARS)
library(cladoRcpp)
library(rexpokit)
library(roxygen2)

#----- Setting WD -----#
setwd("~/Desktop/Aintzane/Mormyridae_Rose") # Set your working directory

#----- Setting up extension data directory -----#
extdata_dir = np(system.file("extdata", package="BioGeoBEARS"))

#----- Loading tree -----#
tree.data = "TREES/Master_tree.tree"
phylo = read.tree(tree.data)
phylo = ladderize(phylo)

#----- Loading geographical data -----#
geog.data = "Code_Biogeo_Mormyridae.txt" #Nilo-Sudan (NS), Lower Guinea (LG), Congo Basin (CB), Upper Guinea (UG), Zambezi (Z), Quanza (Q), East Coast (EC)
moref(geog.data)

tipranges = getranges_from_LagrangePHYLIP(lgdata_fn=geog.data)

####################################
#----- Biogeographical models -----#
####################################
#--------- DEC AND DEC+J ----------#
####################################

#--------- DEC ----------#
BioGeoBEARS_run_object = define_BioGeoBEARS_run()
BioGeoBEARS_run_object$force_sparse=FALSE   
BioGeoBEARS_run_object$speedup=TRUE          
BioGeoBEARS_run_object$calc_ancprobs=TRUE    
BioGeoBEARS_run_object$use_optimx = TRUE

# Setting dispersal probability analysis 
BioGeoBEARS_run_object$dispersal_multipliers_fn = "dispersal_multipliers_M0.txt"

# Input the maximum range size
max_range_size = 5 # Mormyrops_anguilloides distributed in 5 areas
BioGeoBEARS_run_object$max_range_size = max_range_size

# Multicore processing (only if needed)
BioGeoBEARS_run_object$num_cores_to_use=20

# Sparse matrix exponentiation is an option for huge numbers of ranges/states (600+) - Not the present case
BioGeoBEARS_run_object$force_sparse=FALSE

# Give BioGeoBEARS the location of the geography text file
BioGeoBEARS_run_object$geogfn = geog.data

# Give BioGeoBEARS the location of the phylogeny Newick file
BioGeoBEARS_run_object$trfn = tree.data

# Loading the dispersal multiplier matrix and running some checks
BioGeoBEARS_run_object = readfiles_BioGeoBEARS_run(BioGeoBEARS_run_object)

# Good default settings to get ancestral states
BioGeoBEARS_run_object$return_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_TTL_loglike_from_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_ancprobs = TRUE

# Set up DEC model
# (nothing to do; defaults)

# Final check
check_BioGeoBEARS_run(BioGeoBEARS_run_object)

# RUN
runslow = TRUE
resfn = "Mormyridae_DEC_TimeStratified.Rdata"
if (runslow)
{
  res = bears_optim_run(BioGeoBEARS_run_object)
  res    
  
  save(res, file=resfn)
  resDEC = res
} else {
  # Loads to "res"
  load(resfn)
  resDEC = res
}

#--------- DEC+J ----------#

BioGeoBEARS_run_object = define_BioGeoBEARS_run()
BioGeoBEARS_run_object$force_sparse=FALSE   
BioGeoBEARS_run_object$speedup=TRUE          
BioGeoBEARS_run_object$calc_ancprobs=TRUE    
BioGeoBEARS_run_object$use_optimx = TRUE

# Setting dispersal probability analysis 
BioGeoBEARS_run_object$dispersal_multipliers_fn = "dispersal_multipliers_M0.txt"

# Input the maximum range size
max_range_size = 5
BioGeoBEARS_run_object$max_range_size = max_range_size

# Multicore processing (only if needed)
BioGeoBEARS_run_object$num_cores_to_use=20

# Sparse matrix exponentiation is an option for huge numbers of ranges/states (600+) - Not the present case
BioGeoBEARS_run_object$force_sparse=FALSE

# Give BioGeoBEARS the location of the geography text file
BioGeoBEARS_run_object$geogfn = geog.data

# Give BioGeoBEARS the location of the phylogeny Newick file
BioGeoBEARS_run_object$trfn = tree.data

# Loading the dispersal multiplier matrix and running some checks
BioGeoBEARS_run_object = readfiles_BioGeoBEARS_run(BioGeoBEARS_run_object)

# Good default settings to get ancestral states
BioGeoBEARS_run_object$return_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_TTL_loglike_from_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_ancprobs = TRUE

# Set up DEC+J model
dstart = resDEC$outputs@params_table["d","est"]
estart = resDEC$outputs@params_table["e","est"]
jstart = 0.0001

# Input starting values for d, e
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["d","init"] = dstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["d","est"] = dstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["e","init"] = estart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["e","est"] = estart

# Add j as a free parameter
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","type"] = "free"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","init"] = jstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","est"] = jstart

# Final check
check_BioGeoBEARS_run(BioGeoBEARS_run_object)

resfn = "Mormyridae_DEC+J_TimeStratified.Rdata"
runslow = TRUE
if (runslow)
{
  
  res = bears_optim_run(BioGeoBEARS_run_object)
  res    
  
  save(res, file=resfn)
  
  resDECj = res
} else {
  # Loads to "res"
  load(resfn)
  resDECj = res
}

####################################
#----- DIVALIKE AND DIVALIKE+J ----#
####################################

#--------- DIVALIKE ----------#
BioGeoBEARS_run_object = define_BioGeoBEARS_run()
BioGeoBEARS_run_object$force_sparse=FALSE   
BioGeoBEARS_run_object$speedup=TRUE          
BioGeoBEARS_run_object$calc_ancprobs=TRUE    
BioGeoBEARS_run_object$use_optimx = TRUE

# Setting dispersal probability analysis 
BioGeoBEARS_run_object$dispersal_multipliers_fn = "dispersal_multipliers_M0.txt"

# Input the maximum range size
max_range_size = 5
BioGeoBEARS_run_object$max_range_size = max_range_size

# Multicore processing (only if needed)
BioGeoBEARS_run_object$num_cores_to_use=20

# Sparse matrix exponentiation is an option for huge numbers of ranges/states (600+) - Not the present case
BioGeoBEARS_run_object$force_sparse=FALSE

# Give BioGeoBEARS the location of the geography text file
BioGeoBEARS_run_object$geogfn = geog.data

# Give BioGeoBEARS the location of the phylogeny Newick file
BioGeoBEARS_run_object$trfn = tree.data

# Loading the dispersal multiplier matrix and running some checks
BioGeoBEARS_run_object = readfiles_BioGeoBEARS_run(BioGeoBEARS_run_object)

# Good default settings to get ancestral states
BioGeoBEARS_run_object$return_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_TTL_loglike_from_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_ancprobs = TRUE

# Set up DIVALIKE model
# Remove subset-sympatry
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","type"] = "fixed"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","init"] = 0.0
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","est"] = 0.0

BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["ysv","type"] = "2-j"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["ys","type"] = "ysv*1/2"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["y","type"] = "ysv*1/2"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["v","type"] = "ysv*1/2"

# Allow classic, widespread vicariance; all events equiprobable
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01v","type"] = "fixed"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01v","init"] = 0.5
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01v","est"] = 0.5

# Final check
check_BioGeoBEARS_run(BioGeoBEARS_run_object)

# RUN
runslow = TRUE
resfn = "Mormyridae_DIVALIKE_TimeStratified.Rdata"
if (runslow)
{
  res = bears_optim_run(BioGeoBEARS_run_object)
  res    
  
  save(res, file=resfn)
  resDIVALIKE = res
} else {
  # Loads to "res"
  load(resfn)
  resDIVALIKE = res
}

#--------- DIVALIKE+J ----------#

BioGeoBEARS_run_object = define_BioGeoBEARS_run()
BioGeoBEARS_run_object$force_sparse=FALSE   
BioGeoBEARS_run_object$speedup=TRUE          
BioGeoBEARS_run_object$calc_ancprobs=TRUE    
BioGeoBEARS_run_object$use_optimx = TRUE

# Setting dispersal probability analysis 
BioGeoBEARS_run_object$dispersal_multipliers_fn = "dispersal_multipliers_M0.txt"

# Input the maximum range size
max_range_size = 5
BioGeoBEARS_run_object$max_range_size = max_range_size

# Multicore processing (only if needed)
BioGeoBEARS_run_object$num_cores_to_use=20

# Sparse matrix exponentiation is an option for huge numbers of ranges/states (600+) - Not the present case
BioGeoBEARS_run_object$force_sparse=FALSE

# Give BioGeoBEARS the location of the geography text file
BioGeoBEARS_run_object$geogfn = geog.data

# Give BioGeoBEARS the location of the phylogeny Newick file
BioGeoBEARS_run_object$trfn = tree.data

# Loading the dispersal multiplier matrix and running some checks
BioGeoBEARS_run_object = readfiles_BioGeoBEARS_run(BioGeoBEARS_run_object)

# Good default settings to get ancestral states
BioGeoBEARS_run_object$return_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_TTL_loglike_from_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_ancprobs = TRUE

# Set up DIVALIKE+J model
dstart = resDIVALIKE$outputs@params_table["d","est"]
estart = resDIVALIKE$outputs@params_table["e","est"]
jstart = 0.0001

# Input starting values for d, e
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["d","init"] = dstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["d","est"] = dstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["e","init"] = estart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["e","est"] = estart

# Remove subset-sympatry
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","type"] = "fixed"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","init"] = 0.0
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","est"] = 0.0

BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["ysv","type"] = "2-j"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["ys","type"] = "ysv*1/2"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["y","type"] = "ysv*1/2"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["v","type"] = "ysv*1/2"

# Allow classic, widespread vicariance; all events equiprobable
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01v","type"] = "fixed"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01v","init"] = 0.5
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01v","est"] = 0.5

# Add jump dispersal/founder-event speciation
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","type"] = "free"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","init"] = jstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","est"] = jstart

# Under DIVALIKE+J, the max of "j" should be 2, not 3 (as is default in DEC+J)
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","min"] = 0.00001
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","max"] = 1.99999

# Final check
check_BioGeoBEARS_run(BioGeoBEARS_run_object)

# RUN
resfn = "Mormyridae_DIVALIKE+J_TimeStratified.Rdata"
runslow = TRUE
if (runslow)
{
  
  res = bears_optim_run(BioGeoBEARS_run_object)
  res    
  
  save(res, file=resfn)
  
  resDIVALIKEj = res
} else {
  # Loads to "res"
  load(resfn)
  resDIVALIKEj = res
}

####################################
#- BAYAREALIKE AND BAYAREALIKE+J --#
####################################

#--------- BAYAREALIKE ----------#
BioGeoBEARS_run_object = define_BioGeoBEARS_run()
BioGeoBEARS_run_object$force_sparse=FALSE   
BioGeoBEARS_run_object$speedup=TRUE          
BioGeoBEARS_run_object$calc_ancprobs=TRUE    
BioGeoBEARS_run_object$use_optimx = TRUE

# Setting dispersal probability analysis 
BioGeoBEARS_run_object$dispersal_multipliers_fn = "dispersal_multipliers_M0.txt"

# Input the maximum range size
max_range_size = 5
BioGeoBEARS_run_object$max_range_size = max_range_size

# Multicore processing (only if needed)
BioGeoBEARS_run_object$num_cores_to_use=20

# Sparse matrix exponentiation is an option for huge numbers of ranges/states (600+) - Not the present case
BioGeoBEARS_run_object$force_sparse=FALSE

# Give BioGeoBEARS the location of the geography text file
BioGeoBEARS_run_object$geogfn = geog.data

# Give BioGeoBEARS the location of the phylogeny Newick file
BioGeoBEARS_run_object$trfn = tree.data

# Loading the dispersal multiplier matrix and running some checks
BioGeoBEARS_run_object = readfiles_BioGeoBEARS_run(BioGeoBEARS_run_object)

# Good default settings to get ancestral states
BioGeoBEARS_run_object$return_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_TTL_loglike_from_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_ancprobs = TRUE

# Set up BAYAREALIKE model
# No subset sympatry
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","type"] = "fixed"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","init"] = 0.0
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","est"] = 0.0

# No vicariance
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["v","type"] = "fixed"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["v","init"] = 0.0
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["v","est"] = 0.0

# Adjust linkage between parameters
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["ysv","type"] = "1-j"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["ys","type"] = "ysv*1/1"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["y","type"] = "1-j"

# Only sympatric/range-copying (y) events allowed, and with 
# exact copying (both descendants always the same size as the ancestor)
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01y","type"] = "fixed"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01y","init"] = 0.9999
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01y","est"] = 0.9999

# Final check
check_BioGeoBEARS_run(BioGeoBEARS_run_object)

# RUN
runslow = TRUE
resfn = "Mormyridae_BAYAREALIKE_TimeStratified.Rdata"
if (runslow)
{
  res = bears_optim_run(BioGeoBEARS_run_object)
  res    
  
  save(res, file=resfn)
  resBAYAREALIKE = res
} else {
  # Loads to "res"
  load(resfn)
  resBAYAREALIKE = res
}

#--------- BAYAREALIKE+J ----------#

BioGeoBEARS_run_object = define_BioGeoBEARS_run()
BioGeoBEARS_run_object$force_sparse=FALSE   
BioGeoBEARS_run_object$speedup=TRUE          
BioGeoBEARS_run_object$calc_ancprobs=TRUE    
BioGeoBEARS_run_object$use_optimx = TRUE

# Setting dispersal probability analysis 
BioGeoBEARS_run_object$dispersal_multipliers_fn = "dispersal_multipliers_M0.txt"

# Input the maximum range size
max_range_size = 5
BioGeoBEARS_run_object$max_range_size = max_range_size

# Multicore processing (only if needed)
BioGeoBEARS_run_object$num_cores_to_use=20

# Sparse matrix exponentiation is an option for huge numbers of ranges/states (600+) - Not the present case
BioGeoBEARS_run_object$force_sparse=FALSE

# Give BioGeoBEARS the location of the geography text file
BioGeoBEARS_run_object$geogfn = geog.data

# Give BioGeoBEARS the location of the phylogeny Newick file
BioGeoBEARS_run_object$trfn = tree.data

# Loading the dispersal multiplier matrix and running some checks
BioGeoBEARS_run_object = readfiles_BioGeoBEARS_run(BioGeoBEARS_run_object)

# Good default settings to get ancestral states
BioGeoBEARS_run_object$return_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_TTL_loglike_from_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_ancprobs = TRUE

# Set up BAYAREALIKE+J model
dstart = resBAYAREALIKE$outputs@params_table["d","est"]
estart = resBAYAREALIKE$outputs@params_table["e","est"]
jstart = 0.0001

# Input starting values for d, e
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["d","init"] = dstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["d","est"] = dstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["e","init"] = estart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["e","est"] = estart

# No subset sympatry
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","type"] = "fixed"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","init"] = 0.0
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","est"] = 0.0

# No vicariance
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["v","type"] = "fixed"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["v","init"] = 0.0
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["v","est"] = 0.0

# *DO* allow jump dispersal/founder-event speciation (set the starting value close to 0)
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","type"] = "free"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","init"] = jstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","est"] = jstart

# Under BAYAREALIKE+J, the max of "j" should be 1, not 3 (as is default in DEC+J) or 2 (as in DIVALIKE+J)
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","max"] = 0.99999

# Adjust linkage between parameters
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["ysv","type"] = "1-j"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["ys","type"] = "ysv*1/1"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["y","type"] = "1-j"

# Only sympatric/range-copying (y) events allowed, and with 
# exact copying (both descendants always the same size as the ancestor)
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01y","type"] = "fixed"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01y","init"] = 0.9999
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01y","est"] = 0.9999

# setting min and max for d and e to avoid crashing:
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["d","min"] = 0.0000001
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["d","max"] = 4.9999999

BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["e","min"] = 0.0000001
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["e","max"] = 4.9999999

BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","min"] = 0.00001
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","max"] = 0.99999

# Final check
check_BioGeoBEARS_run(BioGeoBEARS_run_object)

# RUN
resfn = "Mormyridae_BAYAREALIKE+J_TimeStratified.Rdata"
runslow = TRUE
if (runslow)
{
  res = bears_optim_run(BioGeoBEARS_run_object)
  res    
  
  save(res, file=resfn)
  
  resBAYAREALIKEj = res
} else {
  # Loads to "res"
  load(resfn)
  resBAYAREALIKEj = res
}

####################################
#--------- +W ANALYSIS ------------#
####################################
#------ DEC+W AND DEC+J+W ---------#
####################################

#--------- DEC+W ----------#
BioGeoBEARS_run_object = define_BioGeoBEARS_run()
BioGeoBEARS_run_object$force_sparse=FALSE   
BioGeoBEARS_run_object$speedup=TRUE          
BioGeoBEARS_run_object$calc_ancprobs=TRUE    
BioGeoBEARS_run_object$use_optimx = TRUE

# Setting dispersal probability analysis 
BioGeoBEARS_run_object$dispersal_multipliers_fn = "dispersal_multipliers_M0.txt"

# Input the maximum range size
max_range_size = 5
BioGeoBEARS_run_object$max_range_size = max_range_size

# Multicore processing (only if needed)
BioGeoBEARS_run_object$num_cores_to_use=20

# Sparse matrix exponentiation is an option for huge numbers of ranges/states (600+) - Not the present case
BioGeoBEARS_run_object$force_sparse=FALSE

# Give BioGeoBEARS the location of the geography text file
BioGeoBEARS_run_object$geogfn = geog.data

# Give BioGeoBEARS the location of the phylogeny Newick file
BioGeoBEARS_run_object$trfn = tree.data

# Loading the dispersal multiplier matrix and running some checks
BioGeoBEARS_run_object = readfiles_BioGeoBEARS_run(BioGeoBEARS_run_object)

# Good default settings to get ancestral states
BioGeoBEARS_run_object$return_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_TTL_loglike_from_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_ancprobs = TRUE

# Set up DEC+W model
# *DO* allow dispersal multipliers exponential
wstart = 0.0001

BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","type"] = "free"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","init"] = wstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","est"] = wstart

# setting min and max w to avoid crashing:
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","min"] = 0.00001
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","max"] = 4.99999

# Final check
check_BioGeoBEARS_run(BioGeoBEARS_run_object)

# RUN
runslow = TRUE
resfn = "Mormyridae_DEC+W_TimeStratified.Rdata"
if (runslow)
{
  res = bears_optim_run(BioGeoBEARS_run_object)
  res    
  
  save(res, file=resfn)
  resDECw = res
} else {
  # Loads to "res"
  load(resfn)
  resDECw = res
}

#--------- DEC+J+W ----------#

BioGeoBEARS_run_object = define_BioGeoBEARS_run()
BioGeoBEARS_run_object$force_sparse=FALSE   
BioGeoBEARS_run_object$speedup=TRUE          
BioGeoBEARS_run_object$calc_ancprobs=TRUE    
BioGeoBEARS_run_object$use_optimx = TRUE

# Setting dispersal probability analysis 
BioGeoBEARS_run_object$dispersal_multipliers_fn = "dispersal_multipliers_M0.txt"

# Input the maximum range size
max_range_size = 5
BioGeoBEARS_run_object$max_range_size = max_range_size

# Multicore processing (only if needed)
BioGeoBEARS_run_object$num_cores_to_use=20

# Sparse matrix exponentiation is an option for huge numbers of ranges/states (600+) - Not the present case
BioGeoBEARS_run_object$force_sparse=FALSE

# Give BioGeoBEARS the location of the geography text file
BioGeoBEARS_run_object$geogfn = geog.data

# Give BioGeoBEARS the location of the phylogeny Newick file
BioGeoBEARS_run_object$trfn = tree.data

# Loading the dispersal multiplier matrix and running some checks
BioGeoBEARS_run_object = readfiles_BioGeoBEARS_run(BioGeoBEARS_run_object)

# Good default settings to get ancestral states
BioGeoBEARS_run_object$return_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_TTL_loglike_from_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_ancprobs = TRUE

# Set up DEC+J+W model
dstart = resDEC$outputs@params_table["d","est"]
estart = resDEC$outputs@params_table["e","est"]
jstart = 0.00001

# Input starting values for d, e
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["d","init"] = dstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["d","est"] = dstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["e","init"] = estart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["e","est"] = estart

# Add j as a free parameter
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","type"] = "free"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","init"] = jstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","est"] = jstart

# *DO* allow dispersal multipliers exponential
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","type"] = "free"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","init"] = wstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","est"] = wstart

# setting min and max w to avoid crashing:
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","min"] = 0.00001
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","max"] = 4.99999

# Final check
check_BioGeoBEARS_run(BioGeoBEARS_run_object)

# RUN
resfn = "Mormyridae_DEC+J+W_TimeStratified.Rdata"
runslow = TRUE
if (runslow)
{
  
  res = bears_optim_run(BioGeoBEARS_run_object)
  res    
  
  save(res, file=resfn)
  
  resDECjw = res
} else {
  # Loads to "res"
  load(resfn)
  resDECjw = res
}

####################################
#--- DIVALIKE+W AND DIVALIKE+J+W --#
####################################

#--------- DIVALIKE+W ----------#
BioGeoBEARS_run_object = define_BioGeoBEARS_run()
BioGeoBEARS_run_object$force_sparse=FALSE   
BioGeoBEARS_run_object$speedup=TRUE          
BioGeoBEARS_run_object$calc_ancprobs=TRUE    
BioGeoBEARS_run_object$use_optimx = TRUE

# Setting dispersal probability analysis 
BioGeoBEARS_run_object$dispersal_multipliers_fn = "dispersal_multipliers_M0.txt"

# Input the maximum range size
max_range_size = 5
BioGeoBEARS_run_object$max_range_size = max_range_size

# Multicore processing (only if needed)
BioGeoBEARS_run_object$num_cores_to_use=20

# Sparse matrix exponentiation is an option for huge numbers of ranges/states (600+) - Not the present case
BioGeoBEARS_run_object$force_sparse=FALSE

# Give BioGeoBEARS the location of the geography text file
BioGeoBEARS_run_object$geogfn = geog.data

# Give BioGeoBEARS the location of the phylogeny Newick file
BioGeoBEARS_run_object$trfn = tree.data

# Loading the dispersal multiplier matrix and running some checks
BioGeoBEARS_run_object = readfiles_BioGeoBEARS_run(BioGeoBEARS_run_object)

# Good default settings to get ancestral states
BioGeoBEARS_run_object$return_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_TTL_loglike_from_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_ancprobs = TRUE

# Set up DIVALIKE+W model
# Remove subset-sympatry
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","type"] = "fixed"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","init"] = 0.0
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","est"] = 0.0

BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["ysv","type"] = "2-j"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["ys","type"] = "ysv*1/2"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["y","type"] = "ysv*1/2"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["v","type"] = "ysv*1/2"

# Allow classic, widespread vicariance; all events equiprobable
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01v","type"] = "fixed"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01v","init"] = 0.5
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01v","est"] = 0.5

# *DO* allow dispersal multipliers exponential
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","type"] = "free"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","init"] = wstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","est"] = wstart

# setting min and max w to avoid crashing:
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","min"] = 0.00001
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","max"] = 4.99999

# Final check
check_BioGeoBEARS_run(BioGeoBEARS_run_object)

# RUN
runslow = TRUE
resfn = "Mormyridae_DIVALIKE+W_TimeStratified.Rdata"
if (runslow)
{
  res = bears_optim_run(BioGeoBEARS_run_object)
  res    
  
  save(res, file=resfn)
  resDIVALIKEw = res
} else {
  # Loads to "res"
  load(resfn)
  resDIVALIKEw = res
}

#--------- DIVALIKE+W+J ----------#

BioGeoBEARS_run_object = define_BioGeoBEARS_run()
BioGeoBEARS_run_object$force_sparse=FALSE   
BioGeoBEARS_run_object$speedup=TRUE          
BioGeoBEARS_run_object$calc_ancprobs=TRUE    
BioGeoBEARS_run_object$use_optimx = TRUE

# Setting dispersal probability analysis 
BioGeoBEARS_run_object$dispersal_multipliers_fn = "dispersal_multipliers_M0.txt"

# Input the maximum range size
max_range_size = 5
BioGeoBEARS_run_object$max_range_size = max_range_size

# Multicore processing (only if needed)
BioGeoBEARS_run_object$num_cores_to_use=20

# Sparse matrix exponentiation is an option for huge numbers of ranges/states (600+) - Not the present case
BioGeoBEARS_run_object$force_sparse=FALSE

# Give BioGeoBEARS the location of the geography text file
BioGeoBEARS_run_object$geogfn = geog.data

# Give BioGeoBEARS the location of the phylogeny Newick file
BioGeoBEARS_run_object$trfn = tree.data

# Loading the dispersal multiplier matrix and running some checks
BioGeoBEARS_run_object = readfiles_BioGeoBEARS_run(BioGeoBEARS_run_object)

# Good default settings to get ancestral states
BioGeoBEARS_run_object$return_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_TTL_loglike_from_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_ancprobs = TRUE

# Set up DIVALIKE+J model
dstart = resDIVALIKE$outputs@params_table["d","est"]
estart = resDIVALIKE$outputs@params_table["e","est"]
jstart = 0.0001

# Input starting values for d, e
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["d","init"] = dstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["d","est"] = dstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["e","init"] = estart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["e","est"] = estart

# Remove subset-sympatry
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","type"] = "fixed"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","init"] = 0.0
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","est"] = 0.0

BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["ysv","type"] = "2-j"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["ys","type"] = "ysv*1/2"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["y","type"] = "ysv*1/2"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["v","type"] = "ysv*1/2"

# Allow classic, widespread vicariance; all events equiprobable
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01v","type"] = "fixed"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01v","init"] = 0.5
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01v","est"] = 0.5

# Add jump dispersal/founder-event speciation
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","type"] = "free"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","init"] = jstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","est"] = jstart

# *DO* allow dispersal multipliers exponential
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","type"] = "free"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","init"] = wstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","est"] = wstart

# setting min and max w to avoid crashing:
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","min"] = 0.00001
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","max"] = 4.99999

# Under DIVALIKE+J, the max of "j" should be 2, not 3 (as is default in DEC+J)
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","min"] = 0.00001
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","max"] = 1.99999

# Final check
check_BioGeoBEARS_run(BioGeoBEARS_run_object)

# RUN
resfn = "Mormyridae_DIVALIKE+J+W_TimeStratified.Rdata"
runslow = TRUE
if (runslow)
{
  
  res = bears_optim_run(BioGeoBEARS_run_object)
  res    
  
  save(res, file=resfn)
  
  resDIVALIKEjw = res
} else {
  # Loads to "res"
  load(resfn)
  resDIVALIKEjw = res
}

#######################################
#- BAYAREALIKE+W AND BAYAREALIKE+J+W -#
#######################################

#--------- BAYAREALIKE+W ----------#
BioGeoBEARS_run_object = define_BioGeoBEARS_run()
BioGeoBEARS_run_object$force_sparse=FALSE   
BioGeoBEARS_run_object$speedup=TRUE          
BioGeoBEARS_run_object$calc_ancprobs=TRUE    
BioGeoBEARS_run_object$use_optimx = TRUE

# Setting dispersal probability analysis 
BioGeoBEARS_run_object$dispersal_multipliers_fn = "dispersal_multipliers_M0.txt"

# Input the maximum range size
max_range_size = 5
BioGeoBEARS_run_object$max_range_size = max_range_size

# Multicore processing (only if needed)
BioGeoBEARS_run_object$num_cores_to_use=20

# Sparse matrix exponentiation is an option for huge numbers of ranges/states (600+) - Not the present case
BioGeoBEARS_run_object$force_sparse=FALSE

# Give BioGeoBEARS the location of the geography text file
BioGeoBEARS_run_object$geogfn = geog.data

# Give BioGeoBEARS the location of the phylogeny Newick file
BioGeoBEARS_run_object$trfn = tree.data

# Loading the dispersal multiplier matrix and running some checks
BioGeoBEARS_run_object = readfiles_BioGeoBEARS_run(BioGeoBEARS_run_object)

# Good default settings to get ancestral states
BioGeoBEARS_run_object$return_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_TTL_loglike_from_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_ancprobs = TRUE

# Set up BAYAREALIKE+W model
# No subset sympatry
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","type"] = "fixed"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","init"] = 0.0
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","est"] = 0.0

# No vicariance
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["v","type"] = "fixed"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["v","init"] = 0.0
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["v","est"] = 0.0

# *DO* allow dispersal multipliers exponential
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","type"] = "free"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","init"] = wstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","est"] = wstart

# Adjust linkage between parameters
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["ysv","type"] = "1-j"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["ys","type"] = "ysv*1/1"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["y","type"] = "1-j"

# Only sympatric/range-copying (y) events allowed, and with 
# exact copying (both descendants always the same size as the ancestor)
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01y","type"] = "fixed"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01y","init"] = 0.9999
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01y","est"] = 0.9999

# setting min and max w to avoid crashing:
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","min"] = 0.00001
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","max"] = 4.99999

# Final check
check_BioGeoBEARS_run(BioGeoBEARS_run_object)

# RUN
runslow = TRUE
resfn = "Mormyridae_BAYAREALIKE+W_TimeStratified.Rdata"
if (runslow)
{
  res = bears_optim_run(BioGeoBEARS_run_object)
  res    
  
  save(res, file=resfn)
  resBAYAREALIKEw = res
} else {
  # Loads to "res"
  load(resfn)
  resBAYAREALIKEw = res
}

#--------- BAYAREALIKE+J+W ----------#

BioGeoBEARS_run_object = define_BioGeoBEARS_run()
BioGeoBEARS_run_object$force_sparse=FALSE   
BioGeoBEARS_run_object$speedup=TRUE          
BioGeoBEARS_run_object$calc_ancprobs=TRUE    
BioGeoBEARS_run_object$use_optimx = TRUE

# Setting dispersal probability analysis 
BioGeoBEARS_run_object$dispersal_multipliers_fn = "dispersal_multipliers_M0.txt"

# Input the maximum range size
max_range_size = 5
BioGeoBEARS_run_object$max_range_size = max_range_size

# Multicore processing (only if needed)
BioGeoBEARS_run_object$num_cores_to_use=20

# Sparse matrix exponentiation is an option for huge numbers of ranges/states (600+) - Not the present case
BioGeoBEARS_run_object$force_sparse=FALSE

# Give BioGeoBEARS the location of the geography text file
BioGeoBEARS_run_object$geogfn = geog.data

# Give BioGeoBEARS the location of the phylogeny Newick file
BioGeoBEARS_run_object$trfn = tree.data

# Loading the dispersal multiplier matrix and running some checks
BioGeoBEARS_run_object = readfiles_BioGeoBEARS_run(BioGeoBEARS_run_object)

# Good default settings to get ancestral states
BioGeoBEARS_run_object$return_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_TTL_loglike_from_condlikes_table = TRUE
BioGeoBEARS_run_object$calc_ancprobs = TRUE

# Set up BAYAREALIKE+J+W model
dstart = resBAYAREALIKEw$outputs@params_table["d","est"]
estart = resBAYAREALIKEw$outputs@params_table["e","est"]
jstart = 0.0001

# Input starting values for d, e
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["d","init"] = dstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["d","est"] = dstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["e","init"] = estart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["e","est"] = estart

# No subset sympatry
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","type"] = "fixed"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","init"] = 0.0
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["s","est"] = 0.0

# No vicariance
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["v","type"] = "fixed"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["v","init"] = 0.0
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["v","est"] = 0.0

# *DO* allow jump dispersal/founder-event speciation (set the starting value close to 0)
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","type"] = "free"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","init"] = jstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","est"] = jstart

# *DO* allow dispersal multipliers exponential
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","type"] = "free"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","init"] = wstart
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","est"] = wstart

# Under BAYAREALIKE+J, the max of "j" should be 1, not 3 (as is default in DEC+J) or 2 (as in DIVALIKE+J)
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","max"] = 0.99999

# Adjust linkage between parameters
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["ysv","type"] = "1-j"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["ys","type"] = "ysv*1/1"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["y","type"] = "1-j"

# Only sympatric/range-copying (y) events allowed, and with 
# exact copying (both descendants always the same size as the ancestor)
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01y","type"] = "fixed"
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01y","init"] = 0.9999
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["mx01y","est"] = 0.9999

# setting min and max to avoid crashing:
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["d","min"] = 0.0000001
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["d","max"] = 4.9999999

BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["e","min"] = 0.0000001
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["e","max"] = 4.9999999

BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","min"] = 0.00001
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["j","max"] = 0.99999

BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","min"] = 0.00001
BioGeoBEARS_run_object$BioGeoBEARS_model_object@params_table["w","max"] = 4.99999

# Final check
check_BioGeoBEARS_run(BioGeoBEARS_run_object)

resfn = "Mormyridae_BAYAREALIKE+J+W_TimeStratified.Rdata"
runslow = TRUE
if (runslow)
{
  res = bears_optim_run(BioGeoBEARS_run_object)
  res    
  
  save(res, file=resfn)
  
  resBAYAREALIKEjw = res
} else {
  # Loads to "res"
  load(resfn)
  resBAYAREALIKEjw = res
}

####################################
#------- SUMMARY STATISTICS -------#
####################################

# Set up empty table to hold the statistical results
restable = NULL

####################################
#----- EXTRACTING PARAMETERS ------#
####################################

#----- DEC ------#

# DEC
res1 = extract_params_from_BioGeoBEARS_results_object(results_object=resDEC, returnwhat="table", addl_params=c("j","w"), paramsstr_digits=4)
# +J
res2 = extract_params_from_BioGeoBEARS_results_object(results_object=resDECj, returnwhat="table", addl_params=c("j","w"), paramsstr_digits=4)
# +W
res3 = extract_params_from_BioGeoBEARS_results_object(results_object=resDECw, returnwhat="table", addl_params=c("j","w"), paramsstr_digits=4)
# +JW
res4 = extract_params_from_BioGeoBEARS_results_object(results_object=resDECjw, returnwhat="table", addl_params=c("j","w"), paramsstr_digits=4)

restable = rbind(restable, res1, res2, res3, res4)

#----- DIVALIKE ------#

# DIVALIKE
res1 = extract_params_from_BioGeoBEARS_results_object(results_object=resDIVALIKE, returnwhat="table", addl_params=c("j","w"), paramsstr_digits=4)
# +J
res2 = extract_params_from_BioGeoBEARS_results_object(results_object=resDIVALIKEj, returnwhat="table", addl_params=c("j","w"), paramsstr_digits=4)
# +W
res3 = extract_params_from_BioGeoBEARS_results_object(results_object=resDIVALIKEw, returnwhat="table", addl_params=c("j","w"), paramsstr_digits=4)
# +JW
res4 = extract_params_from_BioGeoBEARS_results_object(results_object=resDIVALIKEjw, returnwhat="table", addl_params=c("j","w"), paramsstr_digits=4)

restable = rbind(restable, res1, res2, res3, res4)

#----- BAYAREALIKE ------#

# BAYAREALIKE
res1 = extract_params_from_BioGeoBEARS_results_object(results_object=resBAYAREALIKE, returnwhat="table", addl_params=c("j","w"), paramsstr_digits=4)
# +J
res2 = extract_params_from_BioGeoBEARS_results_object(results_object=resBAYAREALIKEj, returnwhat="table", addl_params=c("j","w"), paramsstr_digits=4)
# +W
res3 = extract_params_from_BioGeoBEARS_results_object(results_object=resBAYAREALIKEw, returnwhat="table", addl_params=c("j","w"), paramsstr_digits=4)
# +JW
res4 = extract_params_from_BioGeoBEARS_results_object(results_object=resBAYAREALIKEjw, returnwhat="table", addl_params=c("j","w"), paramsstr_digits=4)

restable = rbind(restable, res1, res2, res3, res4)

####################################
#-------- Assembling table --------#
####################################
row.names(restable) = c("DEC", "DEC+J","DEC+W", "DEC+J+W", "DIVALIKE", "DIVALIKE+J",
                        "DIVALIKE+W", "DIVALIKE+J+W", "BAYAREALIKE", "BAYAREALIKE+J", "BAYAREALIKE+W", "BAYAREALIKE+J+W")
restable = put_jcol_after_ecol(restable)

restable2 = restable

# With AICcs -- factors in sample size
samplesize = length(phylo$tip.label)
AICtable = calc_AICc_column(LnL_vals=restable$LnL, nparam_vals=restable$numparams, samplesize=samplesize)
restable2 = cbind(restable2, AICtable)
restable_AICc_rellike = AkaikeWeights_on_summary_table(restable=restable2, colname_to_use="AICc")
restable_AICc_rellike = put_jcol_after_ecol(restable_AICc_rellike)
restable_AICc_rellike

# Save with nice conditional formatting
write.table(conditional_format_table(restable_AICc_rellike), file="Mormyridae_restable_AICc_formatted.txt", quote=FALSE, sep="\t")

####################################
#---- Plot results best model -----#
####################################

pdf("Mormyridae_pies_DEC.pdf", width=15, height=15)
analysis_titletxt ="DEC Mormyridae"

# Setup
results_object = res
scriptdir = np(system.file("extdata/a_scripts", package="BioGeoBEARS"))

# ML states
plot_BioGeoBEARS_results(results_object, analysis_titletxt, 
                         addl_params=list("j"), plotwhat="text", label.offset=0.55, tipcex=0.4, 
                         statecex=0.4, splitcex=0.4, titlecex=0.8, plotsplits=TRUE, 
                         cornercoords_loc=scriptdir, include_null_range=TRUE, 
                         tr=phylo, tipranges=tipranges)

# Pie chart
plot_BioGeoBEARS_results(results_object, analysis_titletxt, addl_params=list("j"), 
                         plotwhat="pie", label.offset=0.55, tipcex=0.4, statecex=0.4, splitcex=0.4, 
                         titlecex=0.8, plotsplits=TRUE, cornercoords_loc=scriptdir, 
                         include_null_range=TRUE, tr=phylo, tipranges=tipranges)
dev.off()

###################################################